==> org-lsst-ccs-subsystem-fcs-buses-6.1.7-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCarouselSocket.java <==
package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.bus.annotations.SkipEncoding;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterClampState;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.IOModuleStatus;

/**
 * An object that a Carousel Socket publishes on the STATUS bus for trending ddata persister and GUIs.
 * @author virieux
 */
public class StatusDataPublishedByCarouselSocket implements Serializable {
    private static final long serialVersionUID = 353558691508364042L;

    @DataAttributes(description = "IO module status for this socket", units = "unitless")
    private IOModuleStatus ioStatus;

    @DataAttributes(description = "true if this socket is at STANDBY", units = "unitless")
    private boolean atStandby;

    @DataAttributes(description = "clamps state on this socket", units = "unitless")
    private FilterClampState clampsState;

    @DataAttributes(description = "true if this socket is empty : no filter", units = "unitless")
    private boolean empty;

    @SkipEncoding
    private int socketID;

    @SkipEncoding
    private String filterName;

    @DataAttributes(description = "id of filter in this socket", units = "micron")
    private int filterID;

    @SkipEncoding
    private boolean available;

    public IOModuleStatus getIOStatus() {
        return ioStatus;
    }

    public void setIOStatus(IOModuleStatus ioStatus) {
        this.ioStatus = ioStatus;
    }

    public boolean isAtStandby() {
        return atStandby;
    }

    public void setAtStandby(boolean atStandby) {
        this.atStandby = atStandby;
    }

    public FcsEnumerations.FilterClampState getClampState() {
        return clampsState;
    }

    public void setClampsState(FcsEnumerations.FilterClampState clampState) {
        this.clampsState = clampState;
    }
    
    public boolean isEmpty() {
        return empty;
    }

    public void setEmpty(boolean empty) {
        this.empty = empty;
    }

    public String getFilterName() {
        return filterName;
    }

    public void setFilterName(String filterName) {
        this.filterName = filterName;
    }

    public int getFilterID() {
        return filterID;
    }

    public void setFilterID(int filterID) {
        this.filterID = filterID;
    }

    public int getSocketID() {
        return socketID;
    }

    public void setSocketID(int socketID) {
        this.socketID = socketID;
    }

    public boolean isAvailable() {
        return available;
    }

    public void setAvailable(boolean available) {
        this.available = available;
    }
}

==> org-lsst-ccs-subsystem-fcs-buses-6.1.8-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCarouselSocket.java <==
package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.bus.annotations.SkipEncoding;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.FilterClampState;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.IOModuleStatus;

/**
 * An object that a Carousel Socket publishes on the STATUS bus for trending data persister and GUIs.
 * @author virieux
 */
public class StatusDataPublishedByCarouselSocket implements Serializable {
    private static final long serialVersionUID = 353558691508364042L;

    @DataAttributes(description = "IO module status for this socket {UNKNOWN_STATUS; "
        + "IS_SOCKET_AT_STANDBY; IS_READY_NOT_IN_POSITION; ERROR_READING_POSITION; "
        + "SAFE_STATE; BOOTING; NOT_POWERED_ON; NOT_WORKING_FOR_OTHER_REASON}", units = "unitless")
    private IOModuleStatus ioStatus;

    @DataAttributes(description = "is carousel socket at STANDBY position", units = "unitless")
    private boolean atStandby;

    @DataAttributes(description = "clamps state on this socket {READYTOCLAMP; UNCLAMPEDONFILTER; "
        + "UNCLAMPEDEMPTY; CLAMPEDONFILTER; UNDEFINED; ERROR; UNLOCKABLE}", units = "unitless")
    private FilterClampState clampsState;

    @DataAttributes(description = "is the carousel socket empty", units = "unitless")
    private boolean empty;

    @SkipEncoding
    @DataAttributes(description = "id of the carousel socket", units = "unitless")
    private int socketID;

    @SkipEncoding
    @DataAttributes(description = "name of filter in the socket", units = "unitless")
    private String filterName;

    @DataAttributes(description = "id of filter in this socket", units = "micron")
    private int filterID;

    // TODO check units and description
    @SkipEncoding
    private boolean available;

    public IOModuleStatus getIOStatus() {
        return ioStatus;
    }

    public void setIOStatus(IOModuleStatus ioStatus) {
        this.ioStatus = ioStatus;
    }

    public boolean isAtStandby() {
        return atStandby;
    }

    public void setAtStandby(boolean atStandby) {
        this.atStandby = atStandby;
    }

    public FcsEnumerations.FilterClampState getClampState() {
        return clampsState;
    }

    public void setClampsState(FcsEnumerations.FilterClampState clampState) {
        this.clampsState = clampState;
    }

    public boolean isEmpty() {
        return empty;
    }

    public void setEmpty(boolean empty) {
        this.empty = empty;
    }

    public String getFilterName() {
        return filterName;
    }

    public void setFilterName(String filterName) {
        this.filterName = filterName;
    }

    public int getFilterID() {
        return filterID;
    }

    public void setFilterID(int filterID) {
        this.filterID = filterID;
    }

    public int getSocketID() {
        return socketID;
    }

    public void setSocketID(int socketID) {
        this.socketID = socketID;
    }

    public boolean isAvailable() {
        return available;
    }

    public void setAvailable(boolean available) {
        this.available = available;
    }
}
